==> deepin-log-viewer_5.8.32.orig.tar.xz: deepin-log-viewer-5.8.32/translations/deepin-log-viewer_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Megjelenítés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Napló törlése</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Biztosan törölni szeretné a naplót?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Ma</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 napja</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 hete</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 hónapja</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 hónapja</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportálás</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportálás</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Vészhelyzet</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Riasztás</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritikus</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Értesítés</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Hibakeresés</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Bejelentkezés</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Rendszerindítás</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Rendkívül kritikus</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Útvonal</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportálás...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportálás sikeres</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Az exportálás sikertelen</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Fájl exportálása</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periódus:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Szint:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Alkalmazás lista:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Állapot:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Esemény típusa:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Felhasználó:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Művelet:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Rendszerindítási rekord</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Leállítási rekord</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Bejelentkezési rekord</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Hibakeresés</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Vészhelyzet</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritikus</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Értesítés</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Útvonal</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Rendkívül kritikus</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>A naplófájl üres</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Napló Megjelenítő</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>A Napló Megjelenítő egy hasznos alkalmazás a rendszer naplók megtekintéséhez.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Szint</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Folyamat</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Dátum és Idő</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Felhasználó</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Forrás</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Művelet</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Esemény típusa:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Szint:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Folyamat:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Dátum és Idő:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Információ:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nulla</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Felhasználó:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Dátum és Idő</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Rendszer napló</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel napló</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Rendszerindítási napló</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg napló</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin napló</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg napló</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Alkalmazás napló</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Rendszerindítási-Leállítási esemény</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf napló</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.7.orig.tar.xz: deepin-log-viewer-6.0.7/translations/deepin-log-viewer_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Megjelenítés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Napló törlése</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Biztosan törölni szeretné a naplót?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Ma</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 napja</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 hete</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 hónapja</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 hónapja</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportálás</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportálás</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Vészhelyzet</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Riasztás</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritikus</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Értesítés</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Hibakeresés</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Bejelentkezés</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Rendszerindítás</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Rendkívül kritikus</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Útvonal</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportálás...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportálás sikeres</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Az exportálás sikertelen</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Fájl exportálása</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periódus:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Szint:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Alkalmazás lista:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Állapot:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Esemény típusa:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Felhasználó:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Művelet:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Rendszerindítási rekord</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Leállítási rekord</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Bejelentkezési rekord</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Hibakeresés</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Vészhelyzet</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritikus</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Értesítés</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Útvonal</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Rendkívül kritikus</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>A naplófájl üres</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Napló Megjelenítő</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>A Napló Megjelenítő egy hasznos alkalmazás a rendszer naplók megtekintéséhez.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Szint</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Folyamat</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Dátum és Idő</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Felhasználó</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Forrás</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Művelet</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Esemény típusa:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Szint:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Folyamat:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Dátum és Idő:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Információ:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nulla</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Felhasználó:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Dátum és Idő</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Rendszer napló</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel napló</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Rendszerindítási napló</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg napló</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin napló</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg napló</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Alkalmazás napló</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Rendszerindítási-Leállítási esemény</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf napló</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Frissítési gyakoriság</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 másodperc</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 perc</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Nincs frissítés</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Összes exportálása</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Rendszer naplók</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Frissítés most</translation>
    </message>
</context>
</TS>
